@@ -1,11 +1,11 @@
-use persy::{Persy, PersyError, PersyId, Value, ValueMode};
+use persy::{Persy, PersyId, ValueMode};
 use std::path::Path;
 
 ///
 /// Example of insert a record and create a side index that link to the specific record
 ///
 ///
-fn main() -> Result<(), PersyError> {
+fn main() -> Result<(), Box<dyn std::error::Error>> {
     let create_segment;
     if !Path::new("index.exp").exists() {
         Persy::create("index.exp")?;
@@ -18,7 +18,7 @@ fn main() -> Result<(), PersyError> {
     if create_segment {
         let mut tx = persy.begin()?;
         tx.create_segment("data")?;
-        tx.create_index::<String, PersyId>("index", ValueMode::REPLACE)?;
+        tx.create_index::<String, PersyId>("index", ValueMode::Replace)?;
         let prepared = tx.prepare()?;
         prepared.commit()?;
     }
@@ -30,12 +30,10 @@ fn main() -> Result<(), PersyError> {
     let prepared = tx.prepare()?;
     prepared.commit()?;
 
-    let read_id = persy.get::<String, PersyId>("index", &"key".to_string())?;
-    if let Some(is_there) = read_id {
-        if let Value::SINGLE(id) = is_there {
-            let value = persy.read("data", &id)?;
-            assert_eq!(Some(rec.to_vec()), value);
-        }
+    let mut read_id = persy.get::<String, PersyId>("index", &"key".to_string())?;
+    if let Some(id) = read_id.next() {
+        let value = persy.read("data", &id)?;
+        assert_eq!(Some(rec.to_vec()), value);
     }
     Ok(())
 }
