@@ -255,8 +255,6 @@ impl<T: InfallibleRead + InfallibleWrite + PageOps> SegmentPage for T {
         self.seek(SEGMENT_HASH_OFFSET);
         let persistent_id = SegmentId::read(self);
         debug_assert!(persistent_id == segment_id);
-        // TODO: In case of restore this may get a wrong value, so on restore should be
-        // re-calculated from the persistent flags.
         self.seek(pos);
         self.write_u64(record_page);
         self.write_u8(FLAG_EXISTS);
@@ -524,20 +522,6 @@ impl Segments {
         Ok(())
     }
 
-    pub fn recompute_last_pages(&mut self, allocator: &Allocator) -> PERes<()> {
-        for (_, segment) in self.segments.iter_mut() {
-            loop {
-                let mut page = allocator.load_page(segment.last_page)?;
-                let n_page = page.get_next()?;
-                if n_page == 0 {
-                    break;
-                }
-                segment.last_page = n_page;
-            }
-        }
-        Ok(())
-    }
-
     pub fn flush_segments(&mut self, allocator: &Allocator) -> PERes<()> {
         let mut buffer = Vec::<u8>::new();
         for segment in self.segments.values() {
