@@ -10,7 +10,7 @@ use crate::{
 };
 use crate::{
     index::{
-        config::{IndexType, ValueMode},
+        config::{IndexTypeInternal, ValueMode},
         keeper::IndexTransactionKeeper,
         tree::nodes::Value,
     },
@@ -332,13 +332,13 @@ impl TransactionImpl {
         if self.strategy == TxStrategy::VersionOnRead {
             let read = ReadRecord::new(segment, recref, version);
             journal.log(&read, &self.id)?;
-            self.read.insert(recref.clone(), read);
+            self.read.insert(*recref, read);
         }
         Ok(())
     }
 
     pub fn recover_read(&mut self, read: &ReadRecord) {
-        self.read.insert(read.recref.clone(), read.clone());
+        self.read.insert(read.recref, read.clone());
     }
 
     pub fn add_insert(&mut self, journal: &Journal, segment: SegmentId, rec_ref: &RecRef, record: u64) -> PERes<()> {
@@ -399,8 +399,8 @@ impl TransactionImpl {
 
     pub fn add_put<K, V>(&mut self, index: IndexId, k: K, v: V)
     where
-        K: IndexType,
-        V: IndexType,
+        K: IndexTypeInternal,
+        V: IndexTypeInternal,
     {
         if let Some(ref mut indexes) = self.indexes {
             indexes.put(index, k, v);
@@ -409,8 +409,8 @@ impl TransactionImpl {
 
     pub fn add_remove<K, V>(&mut self, index: IndexId, k: K, v: Option<V>)
     where
-        K: IndexType,
-        V: IndexType,
+        K: IndexTypeInternal,
+        V: IndexTypeInternal,
     {
         if let Some(ref mut indexes) = self.indexes {
             indexes.remove(index, k, v);
@@ -421,15 +421,16 @@ impl TransactionImpl {
         &self,
         vm: ValueMode,
         index: IndexId,
+        index_name: &str,
         k: &K,
         pers: Option<Value<V>>,
     ) -> Result<Option<Value<V>>, IndexChangeError>
     where
-        K: IndexType,
-        V: IndexType,
+        K: IndexTypeInternal,
+        V: IndexTypeInternal,
     {
         if let Some(ref indexes) = self.indexes {
-            indexes.apply_changes(index, vm, k, pers)
+            indexes.apply_changes(index, index_name, vm, k, pers)
         } else {
             Ok(pers)
         }
@@ -437,8 +438,8 @@ impl TransactionImpl {
 
     pub fn index_range<K, V, R>(&self, index: IndexId, range: R) -> Option<IntoIter<K>>
     where
-        K: IndexType,
-        V: IndexType,
+        K: IndexTypeInternal,
+        V: IndexTypeInternal,
         R: RangeBounds<K>,
     {
         if let Some(ind) = &self.indexes {
@@ -506,13 +507,13 @@ impl TransactionImpl {
         let mut records = HashSet::new();
         for update in &self.updated {
             if self.locked_index_pages.contains(&update.recref) {
-                records.insert((update.segment, update.recref.clone(), update.version));
+                records.insert((update.segment, update.recref, update.version));
             }
         }
 
         for delete in &self.deleted {
             if self.locked_index_pages.contains(&delete.recref) {
-                records.insert((delete.segment, delete.recref.clone(), delete.version));
+                records.insert((delete.segment, delete.recref, delete.version));
             }
         }
 
@@ -624,12 +625,12 @@ impl TransactionImpl {
         let mut pages_to_free = BTreeSet::new();
         let mut inserted_by_id = HashMap::new();
         for insert in self.inserted.drain(..) {
-            inserted_by_id.insert(insert.recref.clone(), insert);
+            inserted_by_id.insert(insert.recref, insert);
         }
 
         let mut updated_by_id = HashMap::new();
         for update in self.updated.drain(..) {
-            match updated_by_id.entry(update.recref.clone()) {
+            match updated_by_id.entry(update.recref) {
                 Entry::Vacant(e) => {
                     e.insert(update);
                 }
@@ -706,7 +707,7 @@ impl TransactionImpl {
                 version = read_v.version;
             }
             if !self.locked_index_pages.contains(&update.recref) {
-                records.insert((update.segment, update.recref.clone(), version));
+                records.insert((update.segment, update.recref, version));
             }
         }
 
@@ -717,16 +718,16 @@ impl TransactionImpl {
                 version = read_v.version;
             }
             if !self.locked_index_pages.contains(&delete.recref) {
-                records.insert((delete.segment, delete.recref.clone(), version));
+                records.insert((delete.segment, delete.recref, version));
             }
         }
 
         for insert in &self.inserted {
-            records.remove(&(insert.segment, insert.recref.clone(), 1));
+            records.remove(&(insert.segment, insert.recref, 1));
         }
 
         let mut records: Vec<(SegmentId, RecRef, u16)> = records.into_iter().collect();
-        records.sort_by_key(|(_, x, _)| x.clone());
+        records.sort_by_key(|(_, x, _)| *x);
         crt_upd_segs.sort();
         dropped_segs.sort();
         (records, crt_upd_segs, dropped_segs)
@@ -979,12 +980,12 @@ impl TransactionImpl {
         };
 
         if address
-            .check_persistent_records(&[(segment, id.clone(), version)], true)
+            .check_persistent_records(&[(segment, *id, version)], true)
             .is_ok()
         {
             if locked_page {
-                self.locked_index_pages.insert(id.clone());
-                self.locked_index_tracking.insert((segment, id.clone(), version));
+                self.locked_index_pages.insert(*id);
+                self.locked_index_tracking.insert((segment, *id, version));
             }
             Ok(true)
         } else {
@@ -1006,7 +1007,7 @@ impl DeleteRecord {
     pub fn new(segment: SegmentId, rec_ref: &RecRef, version: u16) -> DeleteRecord {
         DeleteRecord {
             segment,
-            recref: rec_ref.clone(),
+            recref: *rec_ref,
             version,
         }
     }
@@ -1016,7 +1017,7 @@ impl UpdateRecord {
     pub fn new(segment: SegmentId, rec_ref: &RecRef, record: u64, version: u16) -> UpdateRecord {
         UpdateRecord {
             segment,
-            recref: rec_ref.clone(),
+            recref: *rec_ref,
             record_page: record,
             version,
         }
@@ -1027,7 +1028,7 @@ impl ReadRecord {
     pub fn new(segment: SegmentId, recref: &RecRef, version: u16) -> ReadRecord {
         ReadRecord {
             segment,
-            recref: recref.clone(),
+            recref: *recref,
             version,
         }
     }
@@ -1061,7 +1062,7 @@ impl InsertRecord {
     pub fn new(segment: SegmentId, rec_ref: &RecRef, record: u64) -> InsertRecord {
         InsertRecord {
             segment,
-            recref: rec_ref.clone(),
+            recref: *rec_ref,
             record_page: record,
         }
     }
